==> vacuum-1.0.1-source.tar.gz: vacuum-1.0.1/src/translations/ru_RU/filetransfer.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU" sourcelanguage="en">
<context>
    <name>FileTransfer</name>
    <message>
        <source>File Transfer</source>
        <translation>Передача файла</translation>
    </message>
    <message>
        <source>Send File</source>
        <translation>Отправить файл</translation>
    </message>
    <message>
        <source>File transfer completed</source>
        <translation>Передача файла завершена</translation>
    </message>
    <message>
        <source>Requested file transfer: %1</source>
        <translation>Запрошена передача файла: %1</translation>
    </message>
    <message>
        <source>You received a request to transfer the file</source>
        <translation>Вы получили запрос на передачу файла</translation>
    </message>
    <message>
        <source>Completed transferring file: %1</source>
        <translation>Завершена передача файла : %1</translation>
    </message>
    <message>
        <source>Canceled transferring file: %1</source>
        <translation>Отменена передача файла: %1</translation>
    </message>
    <message>
        <source>File transfer canceled: %1</source>
        <translation>Передача файла отменена: %1</translation>
    </message>
    <message>
        <source>Auto sending file: %1</source>
        <translation>Автоматическая отправка файла: %1</translation>
    </message>
    <message>
        <source>File sending is started automatically</source>
        <translation>Отправка файла запущена автоматически</translation>
    </message>
    <message>
        <source>Auto receiving file: %1</source>
        <translation>Автоматическое получение файла: %1</translation>
    </message>
    <message>
        <source>File receiving is started automatically</source>
        <translation>Получение файла запущено автоматически</translation>
    </message>
    <message>
        <source>Allows to send a file to another contact</source>
        <translation>Позволяет передать файл другому контакту</translation>
    </message>
    <message>
        <source>Supports the sending of the file to another contact</source>
        <translation>Поддерживает передачу файла другому контакту</translation>
    </message>
</context>
<context>
    <name>FileTransferOptionsClass</name>
    <message>
        <source>Automatically receive files from contacts in roster</source>
        <translation>Автоматически принимать файлы от контактов в ростере</translation>
    </message>
    <message>
        <source>Hide dialog after transfer started</source>
        <translation>Прятать диалог после начала передачи</translation>
    </message>
    <message>
        <source>Automatically remove finished transfers</source>
        <translation>Автоматически удалять завершенные передачи</translation>
    </message>
</context>
<context>
    <name>StreamDialog</name>
    <message>
        <source>Send File - %1</source>
        <translation>Отправить файл - %1</translation>
    </message>
    <message>
        <source>Receive File - %1</source>
        <translation>Получить файл - %1</translation>
    </message>
    <message>
        <source>B</source>
        <comment>Byte</comment>
        <translation>Б</translation>
    </message>
    <message>
        <source>KB</source>
        <comment>Kilobyte</comment>
        <translation>КБ</translation>
    </message>
    <message>
        <source>MB</source>
        <comment>Megabyte</comment>
        <translation>МБ</translation>
    </message>
    <message>
        <source>GB</source>
        <comment>Gigabyte</comment>
        <translation>ГБ</translation>
    </message>
    <message>
        <source>/sec</source>
        <translation>/сек</translation>
    </message>
    <message>
        <source>Select file for receive</source>
        <translation>Выберите файл для приёма</translation>
    </message>
    <message>
        <source>Continue file transfer</source>
        <translation>Продолжить передачу файла</translation>
    </message>
    <message>
        <source>A file with this name, but a smaller size already exists. Do you want to continue file transfer?</source>
        <translation>Файл с таким именем, но меньшим размером, уже существует. Хотите продолжить передачу файла?</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>A file with this name already exists. Do you want to remove existing file?</source>
        <translation>Файл с таким именем уже существует. Хотите удалить существующий файл?</translation>
    </message>
    <message>
        <source>Select file to send</source>
        <translation>Выберите файл для отправки</translation>
    </message>
    <message>
        <source>Unable to send request for file transfer, check settings and try again!</source>
        <translation>Не удалось отправить запрос на передачу файла, проверте настройки и попробуйте еще раз!</translation>
    </message>
    <message>
        <source>Unable to start the file transfer, check settings and try again!</source>
        <translation>Не удалось запустить передачу файла, проверте настройки и попробуйте еще раз!</translation>
    </message>
    <message>
        <source>Are you sure you want to cancel a file transfer?</source>
        <translation>Вы уверешы, что хотите отменить передачу файла?</translation>
    </message>
    <message>
        <source>Cancel file transfer</source>
        <translation>Отмена передачи файла</translation>
    </message>
    <message>
        <source>Can not delete existing file</source>
        <translation>Не могу удалить существующий файл</translation>
    </message>
    <message>
        <source>Remove file</source>
        <translation>Удалить файл</translation>
    </message>
    <message>
        <source>Selected file does not exists</source>
        <translation>Выбранный файл не существует</translation>
    </message>
    <message>
        <source>To:</source>
        <translation>Кому:</translation>
    </message>
    <message>
        <source>From:</source>
        <translation>От:</translation>
    </message>
    <message>
        <source>Transfered %1 of %2.</source>
        <translation>Передано %1 из %2.</translation>
    </message>
    <message>
        <source>Speed %1.</source>
        <translation>Скорость %1.</translation>
    </message>
    <message>
        <source>Selected data stream is not available</source>
        <translation>Выбранный поток данных не доступен</translation>
    </message>
    <message>
        <source>Please select at least one data stream</source>
        <translation>Пожалуйста, выберите хотя бы один поток данных</translation>
    </message>
    <message>
        <source>Data transmission terminated</source>
        <translation>Передача данных прервана</translation>
    </message>
</context>
<context>
    <name>StreamDialogClass</name>
    <message>
        <source>To/From:</source>
        <translation>К/От:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Файл:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <source>Progress:</source>
        <translation>Прогресс:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Статус:</translation>
    </message>
    <message>
        <source>Profile:</source>
        <translation>Профиль:</translation>
    </message>
    <message>
        <source>Select data stream and settings profile</source>
        <translation>Выберите поток данных и профиль настроек</translation>
    </message>
</context>
</TS>

==> vacuum-1.0.2-source.tar.gz: vacuum-1.0.2/src/translations/ru_RU/filetransfer.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU" sourcelanguage="en">
<context>
    <name>FileTransfer</name>
    <message>
        <source>File Transfer</source>
        <translation>Передача файла</translation>
    </message>
    <message>
        <source>Send File</source>
        <translation>Отправить файл</translation>
    </message>
    <message>
        <source>File transfer completed</source>
        <translation>Передача файла завершена</translation>
    </message>
    <message>
        <source>Requested file transfer: %1</source>
        <translation>Запрошена передача файла: %1</translation>
    </message>
    <message>
        <source>You received a request to transfer the file</source>
        <translation>Вы получили запрос на передачу файла</translation>
    </message>
    <message>
        <source>Completed transferring file: %1</source>
        <translation>Завершена передача файла : %1</translation>
    </message>
    <message>
        <source>Canceled transferring file: %1</source>
        <translation>Отменена передача файла: %1</translation>
    </message>
    <message>
        <source>File transfer canceled: %1</source>
        <translation>Передача файла отменена: %1</translation>
    </message>
    <message>
        <source>Auto sending file: %1</source>
        <translation>Автоматическая отправка файла: %1</translation>
    </message>
    <message>
        <source>File sending is started automatically</source>
        <translation>Отправка файла запущена автоматически</translation>
    </message>
    <message>
        <source>Auto receiving file: %1</source>
        <translation>Автоматическое получение файла: %1</translation>
    </message>
    <message>
        <source>File receiving is started automatically</source>
        <translation>Получение файла запущено автоматически</translation>
    </message>
    <message>
        <source>Allows to send a file to another contact</source>
        <translation>Позволяет передать файл другому контакту</translation>
    </message>
    <message>
        <source>Supports the sending of the file to another contact</source>
        <translation>Поддерживает передачу файла другому контакту</translation>
    </message>
</context>
<context>
    <name>FileTransferOptionsClass</name>
    <message>
        <source>Automatically receive files from contacts in roster</source>
        <translation>Автоматически принимать файлы от контактов в ростере</translation>
    </message>
    <message>
        <source>Hide dialog after transfer started</source>
        <translation>Прятать диалог после начала передачи</translation>
    </message>
    <message>
        <source>Automatically remove finished transfers</source>
        <translation>Автоматически удалять завершенные передачи</translation>
    </message>
</context>
<context>
    <name>StreamDialog</name>
    <message>
        <source>Send File - %1</source>
        <translation>Отправить файл - %1</translation>
    </message>
    <message>
        <source>Receive File - %1</source>
        <translation>Получить файл - %1</translation>
    </message>
    <message>
        <source>B</source>
        <comment>Byte</comment>
        <translation>Б</translation>
    </message>
    <message>
        <source>KB</source>
        <comment>Kilobyte</comment>
        <translation>КБ</translation>
    </message>
    <message>
        <source>MB</source>
        <comment>Megabyte</comment>
        <translation>МБ</translation>
    </message>
    <message>
        <source>GB</source>
        <comment>Gigabyte</comment>
        <translation>ГБ</translation>
    </message>
    <message>
        <source>/sec</source>
        <translation>/сек</translation>
    </message>
    <message>
        <source>Select file for receive</source>
        <translation>Выберите файл для приёма</translation>
    </message>
    <message>
        <source>Continue file transfer</source>
        <translation>Продолжить передачу файла</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>A file with this name already exists. Do you want to remove existing file?</source>
        <translation>Файл с таким именем уже существует. Хотите удалить существующий файл?</translation>
    </message>
    <message>
        <source>Select file to send</source>
        <translation>Выберите файл для отправки</translation>
    </message>
    <message>
        <source>Unable to send request for file transfer, check settings and try again!</source>
        <translation>Не удалось отправить запрос на передачу файла, проверте настройки и попробуйте еще раз!</translation>
    </message>
    <message>
        <source>Unable to start the file transfer, check settings and try again!</source>
        <translation>Не удалось запустить передачу файла, проверте настройки и попробуйте еще раз!</translation>
    </message>
    <message>
        <source>Are you sure you want to cancel a file transfer?</source>
        <translation>Вы уверешы, что хотите отменить передачу файла?</translation>
    </message>
    <message>
        <source>Cancel file transfer</source>
        <translation>Отмена передачи файла</translation>
    </message>
    <message>
        <source>Can not delete existing file</source>
        <translation>Не могу удалить существующий файл</translation>
    </message>
    <message>
        <source>Remove file</source>
        <translation>Удалить файл</translation>
    </message>
    <message>
        <source>Selected file does not exists</source>
        <translation>Выбранный файл не существует</translation>
    </message>
    <message>
        <source>To:</source>
        <translation>Кому:</translation>
    </message>
    <message>
        <source>From:</source>
        <translation>От:</translation>
    </message>
    <message>
        <source>Transfered %1 of %2.</source>
        <translation>Передано %1 из %2.</translation>
    </message>
    <message>
        <source>Speed %1.</source>
        <translation>Скорость %1.</translation>
    </message>
    <message>
        <source>Selected data stream is not available</source>
        <translation>Выбранный поток данных не доступен</translation>
    </message>
    <message>
        <source>Please select at least one data stream</source>
        <translation>Пожалуйста, выберите хотя бы один поток данных</translation>
    </message>
    <message>
        <source>Data transmission terminated</source>
        <translation>Передача данных прервана</translation>
    </message>
    <message>
        <source>A file with this name, but a smaller size already exists.</source>
        <translation>Файл с таким именем, но с меньшим размером уже существует.</translation>
    </message>
    <message>
        <source>If you want to change file name press &apos;Cancel&apos;</source>
        <translation>Если хотите изменить имя файла, нажмине &apos;Отмена&apos;</translation>
    </message>
    <message>
        <source>If you want to download the rest of file press &apos;Yes&apos;</source>
        <translation>Если хотите загрузить остаток файла, нажмине &apos;Да&apos;</translation>
    </message>
    <message>
        <source>If you want to start download from the beginning press &apos;Retry&apos;</source>
        <translation>Если хотите заново загрузить весь файл, нажмите &apos;Повторить&apos;</translation>
    </message>
</context>
<context>
    <name>StreamDialogClass</name>
    <message>
        <source>To/From:</source>
        <translation>К/От:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Файл:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <source>Progress:</source>
        <translation>Прогресс:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Статус:</translation>
    </message>
    <message>
        <source>Profile:</source>
        <translation>Профиль:</translation>
    </message>
    <message>
        <source>Select data stream and settings profile</source>
        <translation>Выберите поток данных и профиль настроек</translation>
    </message>
</context>
</TS>
